==> pdf-model-arlington-1.26.8-sources.jar: org/verapdf/model/alayer/AResource.java <==
/**
 * This file is part of veraPDF Validation Model API, a module of the veraPDF project.
 * Copyright (c) 2015, veraPDF Consortium <info@verapdf.org>
 * All rights reserved.
 *
 * veraPDF Validation Model API is free software: you can redistribute it and/or modify
 * it under the terms of either:
 *
 * The GNU General public license GPLv3+.
 * You should have received a copy of the GNU General Public License
 * along with veraPDF Validation Model API as the LICENSE.GPL file in the root of the source
 * tree.  If not, see http://www.gnu.org/licenses/ or
 * https://www.gnu.org/licenses/gpl-3.0.en.html.
 *
 * The Mozilla Public License MPLv2+.
 * You should have received a copy of the Mozilla Public License along with
 * veraPDF Validation Model API as the LICENSE.MPL file in the root of the source tree.
 * If a copy of the MPL was not distributed with this file, you can obtain one at
 * http://mozilla.org/MPL/2.0/.
 */
package org.verapdf.model.alayer;
		
import org.verapdf.model.baselayer.Object;

		
/**
*/
public interface AResource extends AObject {
	









	/**
	*/
	public Boolean getcontainsColorSpace();

	/**
	*/
	public String getColorSpaceType();

	/**
	*/
	public Boolean getColorSpaceHasTypeDictionary();

	/**
	*/
	public Boolean getcontainsExtGState();

	/**
	*/
	public String getExtGStateType();

	/**
	*/
	public Boolean getExtGStateHasTypeDictionary();

	/**
	*/
	public Boolean getcontainsFont();

	/**
	*/
	public String getFontType();

	/**
	*/
	public Boolean getFontHasTypeDictionary();

	/**
	*/
	public Boolean getcontainsPattern();

	/**
	*/
	public String getPatternType();

	/**
	*/
	public Boolean getPatternHasTypeDictionary();

	/**
	*/
	public Boolean getcontainsProcSet();

	/**
	*/
	public String getProcSetType();

	/**
	*/
	public Boolean getProcSetHasTypeArray();

	/**
	*/
	public Boolean getcontainsProperties();

	/**
	*/
	public String getentryPropertiesType();

	/**
	*/
	public Boolean getentryPropertiesHasTypeDictionary();

	/**
	*/
	public Boolean getcontainsShading();

	/**
	*/
	public String getShadingType();

	/**
	*/
	public Boolean getShadingHasTypeDictionary();

	/**
	*/
	public Boolean getcontainsXObject();

	/**
	*/
	public String getXObjectType();

	/**
	*/
	public Boolean getXObjectHasTypeDictionary();
}

==> pdf-model-arlington-1.27.13-sources.jar: org/verapdf/model/alayer/AResource.java <==
/**
 * This file is part of veraPDF Validation Model API, a module of the veraPDF project.
 * Copyright (c) 2015, veraPDF Consortium <info@verapdf.org>
 * All rights reserved.
 *
 * veraPDF Validation Model API is free software: you can redistribute it and/or modify
 * it under the terms of either:
 *
 * The GNU General public license GPLv3+.
 * You should have received a copy of the GNU General Public License
 * along with veraPDF Validation Model API as the LICENSE.GPL file in the root of the source
 * tree.  If not, see http://www.gnu.org/licenses/ or
 * https://www.gnu.org/licenses/gpl-3.0.en.html.
 *
 * The Mozilla Public License MPLv2+.
 * You should have received a copy of the Mozilla Public License along with
 * veraPDF Validation Model API as the LICENSE.MPL file in the root of the source tree.
 * If a copy of the MPL was not distributed with this file, you can obtain one at
 * http://mozilla.org/MPL/2.0/.
 */
package org.verapdf.model.alayer;
		
import org.verapdf.model.baselayer.Object;

		
/**
*/
public interface AResource extends AObject {
	










	/**
	*/
	public Boolean getcontainsColorSpace();

	/**
	*/
	public String getColorSpaceType();

	/**
	*/
	public Boolean getColorSpaceHasTypeDictionary();

	/**
	*/
	public Boolean getcontainsEncoding();

	/**
	*/
	public String getEncodingType();

	/**
	*/
	public Boolean getEncodingHasTypeDictionary();

	/**
	*/
	public Boolean getcontainsExtGState();

	/**
	*/
	public String getExtGStateType();

	/**
	*/
	public Boolean getExtGStateHasTypeDictionary();

	/**
	*/
	public Boolean getcontainsFont();

	/**
	*/
	public String getFontType();

	/**
	*/
	public Boolean getFontHasTypeDictionary();

	/**
	*/
	public Boolean getcontainsPattern();

	/**
	*/
	public String getPatternType();

	/**
	*/
	public Boolean getPatternHasTypeDictionary();

	/**
	*/
	public Boolean getcontainsProcSet();

	/**
	*/
	public String getProcSetType();

	/**
	*/
	public Boolean getProcSetHasTypeArray();

	/**
	*/
	public Boolean getcontainsProperties();

	/**
	*/
	public String getentryPropertiesType();

	/**
	*/
	public Boolean getentryPropertiesHasTypeDictionary();

	/**
	*/
	public Boolean getcontainsShading();

	/**
	*/
	public String getShadingType();

	/**
	*/
	public Boolean getShadingHasTypeDictionary();

	/**
	*/
	public Boolean getcontainsXObject();

	/**
	*/
	public String getXObjectType();

	/**
	*/
	public Boolean getXObjectHasTypeDictionary();
}
